import { latex_types } from "./symbol_types";

var required_latexsym = "Required package \"latexsym\"";
var required_amsmath = "Required package \"amsmath\"";

export default {
	begin: {
		detail: "\\begin{<environment>} ... \\end{<environment>}",
		insertText: "begin{$1}\n\t$0\n\\end{$1}",
		documentation: "Environment Snippet",
		kind: latex_types.snippet
	},

	operatorname: { insertText: "operatorname{$1}$0", documentation: "displays content as operator", kind: latex_types.function },

  "label": { insertText: "label{$1}$0", documentation: "Creates a reference with a number to refere it by the \"ref\" command.", kind: latex_types.keyword },
  "tag": { insertText: "tag{$1}$0", documentation: "Creates a reference with name to refere it by the \"ref\" command by the taged name.", kind: latex_types.keyword },
  "ref": { insertText: "ref{$1}$0", documentation: "Reference", kind: latex_types.keyword },
  "eqref": { insertText: "eqref{$1}$0", documentation: "Equation reference", kind: latex_types.keyword },
  "pageref": { insertText: "pageref{$1}$0", documentation: "Page reference", kind: latex_types.keyword },
  "nonumber": { insertText: "nonumber", documentation: "Removes line number in numberd math environments like \"align\".", kind: latex_types.keyword },

  "left(": { insertText: "left( $1 \\right)$0", documentation: "Left - Right Braces", kind: latex_types.snippet },
  "left[": { insertText: "left[ $1 \\right]$0", documentation: "Left - Right [ Braces", kind: latex_types.snippet },
  "left\\{": { insertText: "left\\{ $1 \\right\\{$0", documentation: "Left - Right \\{ Braces", kind: latex_types.snippet },
  "left|": { insertText: "left| $1 \\right|$0", documentation: "Left - Right Absolutes", kind: latex_types.snippet },

  "bmod": { insertText: "bmod{$1}$0", documentation: "\(binary\) modulo", kind: latex_types.symbol },
  "pmod": { insertText: "pmod{$1}$0", documentation: "modulo", kind: latex_types.symbol },

  "binom": { insertText: "binom{$1}{$2}$0", documentation: "Binomial Coefficient", kind: latex_types.function },
  "frac": { insertText: "frac{$1}{$2}$0", documentation: "Fraction", kind: latex_types.function },
  "cfrac": { insertText: "cfrac{$1}{$2}$0", documentation: "Continued Fraction", kind: latex_types.function },
  "tfrac": { insertText: "tfrac{$1}{$2}$0", documentation: "Text style Fraction", kind: latex_types.function },
  "dfrac": { insertText: "dfrac{$1}{$2}$0", documentation: "Display style Fraction", kind: latex_types.function },
  "genfrac": { insertText: "\\genfrac{${1:left-delim}}{${2:right-delim}}{${3:thickness}}{${4:mathstyle}}{${5:numerator}}{${6:denominator}}$0", documentation: "Generic Fraction", detail: "\\genfrac{<left-delim>}{<right-delim>}{<thickness>}{<mathstyle>}{<numerator>}{<denominator>}", kind: latex_types.function },
  "sqrt": { insertText: "sqrt{$1}$0", documentation: "square root", kind: latex_types.function },
  "sqrt[]": { insertText: "sqrt[]{$1}$0", detail: "\\sqrt[<n>]{<expr>}", documentation: "The <n>-th root of <expr>.", kind: latex_types.function },

  "lim": { insertText: "lim_{$1}$0", documentation: "Limes", kind: latex_types.function },
  "sup": { insertText: "sup_{$1}$0", documentation: "sup", kind: latex_types.function },
  "inf": { insertText: "inf_{$1}$0", documentation: "infimum", kind: latex_types.function },
  "liminf": { insertText: "liminf_{$1}$0", documentation: "liminf", kind: latex_types.function },
  "limsup": { insertText: "limsup_{$1}$0", documentation: "limsup", kind: latex_types.function },
  "max": { insertText: "max_{$1}$0", documentation: "max", kind: latex_types.function },
  "min": { insertText: "min_{$1}$0", documentation: "min", kind: latex_types.function },
  "arg": { insertText: "arg", documentation: "argument", kind: latex_types.symbol },
  "deg": { insertText: "deg", documentation: "degrie", kind: latex_types.symbol },
  "det": { insertText: "det", documentation: "determinant", kind: latex_types.symbol },
  "dim": { insertText: "dim", documentation: "dimention", kind: latex_types.symbol },
  "exp": { insertText: "exp", documentation: "exponential", kind: latex_types.symbol },
  "gcd": { insertText: "gcd", documentation: "Gradest Comon Devider", kind: latex_types.symbol },
  "hom": { insertText: "hom", documentation: "hom", kind: latex_types.symbol },
  "ker": { insertText: "ker", documentation: "kern", kind: latex_types.symbol },
  "lg": { insertText: "lg", documentation: "lg", kind: latex_types.symbol },
  "Pr": { insertText: "Pr", documentation: "Pr", kind: latex_types.symbol },
  
  "text": { insertText: "text{$1}$0", documentation: "Text Mode in math environment", kind: latex_types.function },
  "intertext": { insertText: "intertext{$1}$0", documentation: "Inserts text lines inside math environments", kind: latex_types.function },
  
  "phantom": { insertText: "phantom{$1}$0", documentation: "Occupies space used by expression without displaying the expression.", kind: latex_types.function },

  "mathrm": { insertText: "mathrm{$1}$0", documentation: "Roman Font", kind: latex_types.function },
  "mathbf": { insertText: "mathbf{$1}$0", documentation: "Boldface Font", kind: latex_types.function, detail: "Required package \"amsbsy\" or \"amsmath\". Use \\boldsymbol{} instead." },
  "mathsf": { insertText: "mathsf{$1}$0", documentation: "Sans Serif Font", kind: latex_types.function },
  "mathtt": { insertText: "mathtt{$1}$0", documentation: "Typewriter Font", kind: latex_types.function },
  "mathit": { insertText: "mathit{$1}$0", documentation: "Italic Font", kind: latex_types.function },
  "mathbb": { insertText: "mathbb{$1}$0", documentation: "Blackbord Font", kind: latex_types.function, detail: "Required package \"amsfonts\" or \"amssymb\"" },
  "mathnormal": { insertText: "mathnormal{$1}$0", documentation: "Normal Font", kind: latex_types.function },
  "boldsymbol": { insertText: "boldsymbol{$1}$0", detail: "Required package \"amsbsy\" or \"amsmath\".", documentation: "Bold Symbols in math mode", kind: latex_types.function },
  "mathcal": { insertText: "mathcal{$1}$0", documentation: "Calligraphic Font", kind: latex_types.function },
  "mathscr": { insertText: "mathscr{$1}$0", detail: "Required package \"mathrsfs\"", documentation: "Calegraphic math font", kind: latex_types.function },
  "mathfrac": { insertText: "mathfrac{$1}$0", detail: "Required package \"amsfonts\" or \"amssymb\"", documentation: "Fractal Math Symbols", kind: latex_types.function },

  "displaystyle": { insertText: "displaystyle{$1}$0", documentation: "Sets style to display mode", kind: latex_types.function },
  "textstyle": { insertText: "textstyle{$1}$0", documentation: "Sets style to text mode", kind: latex_types.function },
  "scriptstyle": { insertText: "scriptstyle{$1}$0", documentation: "Sets style to script mode", kind: latex_types.function },
  "scriptscriptstyle": { insertText: "scriptscriptstyle{$1}$0", documentation: "Sets style to 'double' script mode", kind: latex_types.function },

  "overline": { insertText: "overline{$1}$0", documentation: "horizontal line over the expression.", kind: latex_types.function },
  "underline": { insertText: "underline{$1}$0", documentation: "horizontal line under the expression.", kind: latex_types.function },
  "underbrace": { insertText: "underbrace{$1}_{$2}$0", documentation: "long horizontal braces under an expression", kind: latex_types.snippet },
  "overbrace": { insertText: "overbrace{$1}^{$2}$0", documentation: "long horizontal braces over an expression", kind: latex_types.snippet },

  "bar": { insertText: "bar{$1}$0", documentation: "Math Mode Accent: bar", kind: latex_types.function },
  "hat": { insertText: "hat{$1}$0", documentation: "Math Mode Accent: hat", kind: latex_types.function },
  "widehat": { insertText: "widehat{$1}$0", documentation: "Math Mode Accent: widehat", kind: latex_types.function },
  "tilde": { insertText: "tilde{$1}$0", documentation: "Math Mode Accent: tilde", kind: latex_types.function },
  "widetilde": { insertText: "widetilde{$1}$0", documentation: "Math Mode Accent: widetilde", kind: latex_types.function },
  "vec": { insertText: "vec{$1}$0", documentation: "Math Mode Accent: Vector", kind: latex_types.function },
  "grave": { insertText: "grave{$1}$0", documentation: "Math Mode Accent: grave", kind: latex_types.function },
  "acute": { insertText: "acute{$1}$0", documentation: "Math Mode Accent: acute", kind: latex_types.function },
  "mathring": { insertText: "mathring{$1}$0", documentation: "Math Mode Accent: mathring", kind: latex_types.function },
  "check": { insertText: "check{$1}$0", documentation: "Math Mode Accent: check", kind: latex_types.function },
  "dot": { insertText: "dot{$1}$0", documentation: "Math Mode Accent: dot", kind: latex_types.function },
  "breve": { insertText: "breve{$1}$0", documentation: "Math Mode Accent: breve", kind: latex_types.function },
  "ddot": { insertText: "ddot{$1}$0", documentation: "Math Mode Accent: double dot", kind: latex_types.function },
  "overrightarrow": { insertText: "overrightarrow{$1}$0", documentation: "Math Mode Accent: overrightarrow", kind: latex_types.function },
  "overleftarrow": { insertText: "overleftarrow{$1}$0", documentation: "Math Mode Accent: overleftarrow", kind: latex_types.function },
  "overleftrightarrow": { insertText: "overleftrightarrow{$1}$0", documentation: "Math Mode Accent: overleftrightarrow", kind: latex_types.function },
  "underrightarrow": { insertText: "underrightarrow{$1}$0", documentation: "Math Mode Accent: underrightarrow", kind: latex_types.function },
  "underleftarrow": { insertText: "underleftarrow{$1}$0", documentation: "Math Mode Accent: underleftarrow", kind: latex_types.function },
  "underleftrightarrow": { insertText: "underleftrightarrow{$1}$0", documentation: "Math Mode Accent: underleftrightarrow", kind: latex_types.function },

  "alpha": { insertText: "alpha", documentation: "alpha", kind: latex_types.symbol },
  "beta": { insertText: "beta", documentation: "beta", kind: latex_types.symbol },
  "gamma": { insertText: "gamma", documentation: "gamma", kind: latex_types.symbol },
  "Gamma": { insertText: "Gamma", documentation: "Gamma", kind: latex_types.symbol },
  "delta": { insertText: "delta", documentation: "delta", kind: latex_types.symbol },
  "Delta": { insertText: "Delta", documentation: "Delta", kind: latex_types.symbol },
  "epsilon": { insertText: "epsilon", documentation: "epsilon", kind: latex_types.symbol },
  "varepsilon": { insertText: "varepsilon", documentation: "varepsilon", kind: latex_types.symbol },
  "zeta": { insertText: "zeta", documentation: "zeta", kind: latex_types.symbol },
  "eta": { insertText: "eta", documentation: "eta", kind: latex_types.symbol },
  "theta": { insertText: "theta", documentation: "theta", kind: latex_types.symbol },
  "Theta": { insertText: "Theta", documentation: "Theta", kind: latex_types.symbol },
  "vartheta": { insertText: "vartheta", documentation: "vartheta", kind: latex_types.symbol },
  "iota": { insertText: "iota", documentation: "iota", kind: latex_types.symbol },
  "kappa": { insertText: "kappa", documentation: "kappa", kind: latex_types.symbol },
  "varkappa": { insertText: "varkappa", documentation: "varkappa", kind: latex_types.symbol },
  "lambda": { insertText: "lambda", documentation: "lambda", kind: latex_types.symbol },
  "Lambda": { insertText: "Lambda", documentation: "Lambda", kind: latex_types.symbol },
  "mu": { insertText: "mu", documentation: "mu", kind: latex_types.symbol },
  "nu": { insertText: "nu", documentation: "nu", kind: latex_types.symbol },
  "xi": { insertText: "xi", documentation: "xi", kind: latex_types.symbol },
  "Xi": { insertText: "Xi", documentation: "Xi", kind: latex_types.symbol },
  "pi": { insertText: "pi", documentation: "pi", kind: latex_types.symbol },
  "Pi": { insertText: "Pi", documentation: "Pi", kind: latex_types.symbol },
  "varpi": { insertText: "varpi", documentation: "varpi", kind: latex_types.symbol },
  "rho": { insertText: "rho", documentation: "rho", kind: latex_types.symbol },
  "varrho": { insertText: "varrho", documentation: "varrho", kind: latex_types.symbol },
  "sigma": { insertText: "sigma", documentation: "sigma", kind: latex_types.symbol },
  "Sigma": { insertText: "Sigma", documentation: "Sigma", kind: latex_types.symbol },
  "varsigma": { insertText: "varsigma", documentation: "varsigma", kind: latex_types.symbol },
  "tau": { insertText: "tau", documentation: "tau", kind: latex_types.symbol },
  "upsilon": { insertText: "upsilon", documentation: "upsilon", kind: latex_types.symbol },
  "Upsilon": { insertText: "Upsilon", documentation: "Upsilon", kind: latex_types.symbol },
  "phi": { insertText: "phi", documentation: "phi", kind: latex_types.symbol },
  "Phi": { insertText: "Phi", documentation: "Phi", kind: latex_types.symbol },
  "varphi": { insertText: "varphi", documentation: "varphi", kind: latex_types.symbol },
  "chi": { insertText: "chi", documentation: "chi", kind: latex_types.symbol },
  "psi": { insertText: "psi", documentation: "psi", kind: latex_types.symbol },
  "Psi": { insertText: "Psi", documentation: "Psi", kind: latex_types.symbol },
  "omega": { insertText: "omega", documentation: "omega", kind: latex_types.symbol },
  "Omega": { insertText: "Omega", documentation: "Omega", kind: latex_types.symbol },

  "sin": { documentation: "Sinus", kind: latex_types.symbol },
  "cos": { documentation: "Cosinus", kind: latex_types.symbol },
  "tan": { documentation: "Tangens", kind: latex_types.symbol },
  "arcsin": { documentation: "Arcus Sinus", kind: latex_types.symbol },
  "arccos": { documentation: "Arcus Cosinus", kind: latex_types.symbol },
  "sinh": { documentation: "Sinus Hyperbolicus", kind: latex_types.symbol },
  "cosh": { documentation: "Cosinus Hyperbolicus", kind: latex_types.symbol },
  "tanh": { documentation: "Tangens Hyperbolicus", kind: latex_types.symbol },
  "sec": { documentation: "sec", kind: latex_types.symbol },
  "csc": { documentation: "csc", kind: latex_types.symbol },
  "arctan": { documentation: "arctan", kind: latex_types.symbol },
  "cot": { documentation: "cot", kind: latex_types.symbol },
  "arccot": { documentation: "arccot", kind: latex_types.symbol },
  "coth": { documentation: "coth", kind: latex_types.symbol },

  "xrightarrow": { insertText: "xrightarrow[]{$1}$0", documentation: "right arrow with documentation", kind: latex_types.function },
  "xRightarrow": { insertText: "xRightarrow[]{$1}$0", documentation: "right double arrow with documentation", kind: latex_types.function },
  "xleftarrow": { insertText: "xleftarrow[]{$1}$0", documentation: "left arrow with documentation", kind: latex_types.function },
  "xLeftarrow": { insertText: "xReftarrow[]{$1}$0", documentation: "left double arrow with documentation", kind: latex_types.function },

  "stackrel": { insertText: "stackrel{$1}{$2}$0", documentation: "\\stackrel{#1}{#2} puts the symbol given in #1 in superscript-like size over #2 which is set in its usual position.", kind: latex_types.function },
  "substack": { insertText: "substack{$1\\\\$2}$0", documentation: "\\substack{#1}{#2} stacks #1 over #2 in superscript's. For more lines add \"\\\\\".", kind: latex_types.function },

  // "cdot": { insertText: "cdot", documentation: "A centered dot. For example used for a * b.", kind: latex_types.symbol },
  "vdots": { insertText: "vdots", documentation: "3 vertical Dots", kind: latex_types.symbol },
  "ldots": { insertText: "ldots", documentation: "3 lower dots", kind: latex_types.symbol },
  "dots": { insertText: "dots", documentation: "3 Dots", kind: latex_types.symbol },
  "ddots": { insertText: "ddots", documentation: "Diagonal Dots", kind: latex_types.symbol },
  "cdots": { insertText: "cdots", documentation: "3 Centered Dots", kind: latex_types.symbol },
  "iddot": { insertText: "iddot", documentation: "iddot", kind: latex_types.symbol },

  "infty": { insertText: "infty", documentation: "Infinity", kind: latex_types.symbol },
  "triangl": { insertText: "triangl", documentation: "Triangl", kind: latex_types.symbol },
  "aleph": { insertText: "aleph", documentation: "aleph", kind: latex_types.symbol },
  "imath": { insertText: "imath", documentation: "imath", kind: latex_types.symbol },
  "jmath": { insertText: "jmath", documentation: "jmath", kind: latex_types.symbol },
  "ell": { insertText: "ell", documentation: "ell", kind: latex_types.symbol },
  "w": { insertText: "w", documentation: "w", kind: latex_types.symbol },
  "Re": { insertText: "Re", documentation: "Re", kind: latex_types.symbol },
  "Im": { insertText: "Im", documentation: "Im", kind: latex_types.symbol },
  "mh": { insertText: "mh", documentation: "mh", kind: latex_types.symbol },
  "prime": { insertText: "prime", documentation: "prime", kind: latex_types.symbol },
  "emptyset": { insertText: "emptyset", documentation: "emptyset", kind: latex_types.symbol },
  "nabla": { insertText: "nabla", documentation: "nabla", kind: latex_types.symbol },
  "surd": { insertText: "surd", documentation: "surd", kind: latex_types.symbol },
  "partial": { insertText: "partial", documentation: "partial", kind: latex_types.symbol },
  "bot": { insertText: "bot", documentation: "bot", kind: latex_types.symbol },
  "dash": { insertText: "dash", documentation: "dash", kind: latex_types.symbol },
  "forall": { insertText: "forall", documentation: "forall", kind: latex_types.symbol },
  "exists": { insertText: "exists", documentation: "exists", kind: latex_types.symbol },
  "flat": { insertText: "flat", documentation: "flat", kind: latex_types.symbol },
  "natural": { insertText: "natural", documentation: "natural", kind: latex_types.symbol },
  "shar": { insertText: "shar", documentation: "shar", kind: latex_types.symbol },
  "backslash": { insertText: "backslash", documentation: "backslash", kind: latex_types.symbol },
  "Box": { insertText: "Box", documentation: "Box", kind: latex_types.symbol },
  "Diamon": { insertText: "Diamon", documentation: "Diamon", kind: latex_types.symbol },
  "clubsuit": { insertText: "clubsuit", documentation: "clubsuit", kind: latex_types.symbol },
  "diamondsuit": { insertText: "diamondsuit", documentation: "diamondsuit", kind: latex_types.symbol },
  "heartsuit": { insertText: "heartsuit", documentation: "heartsuit", kind: latex_types.symbol },
  "spadesuit": { insertText: "spadesuit", documentation: "spadesuit", kind: latex_types.symbol },
  "blacksquar": { insertText: "blacksquar", documentation: "blacksquar", kind: latex_types.symbol },
  "S": { insertText: "S", documentation: "S", kind: latex_types.symbol },
  "P": { insertText: "P", documentation: "P", kind: latex_types.symbol },
  "copyright": { insertText: "copyright", documentation: "copyright", kind: latex_types.symbol },
  "pounds": { insertText: "pounds", documentation: "pounds", kind: latex_types.symbol },
  "smiley": { insertText: "smiley", documentation: "smiley", kind: latex_types.symbol },
  "checkmark": { insertText: "checkmark", documentation: "checkmark", kind: latex_types.symbol },

  "quad": { insertText: "quad", documentation: "A big Space", kind: latex_types.symbol },
  "qquad": { insertText: "qquad", documentation: "A bigger Space", kind: latex_types.symbol },


  "not": { insertText: "not", documentation: "Use \"\\not\" as prefix of some Binary Relation's to negate them.", kind: latex_types.symbol },
  "leq": { insertText: "leq", documentation: "Binary Relation: leq", kind: latex_types.symbol },
  "ll": { insertText: "ll", documentation: "Binary Relation: ll", kind: latex_types.symbol },
  "prec": { insertText: "prec", documentation: "Binary Relation: prec", kind: latex_types.symbol },
  "preceq": { insertText: "preceq", documentation: "Binary Relation: preceq", kind: latex_types.symbol },
  "subset": { insertText: "subset", documentation: "Binary Relation: subset", kind: latex_types.symbol },
  "subseteq": { insertText: "subseteq", documentation: "Binary Relation: subseteq", kind: latex_types.symbol },
  "sqsubseteq": { insertText: "sqsubseteq", documentation: "Binary Relation: sqsubseteq", kind: latex_types.symbol },
  "in": { insertText: "in", documentation: "Binary Relation: in", kind: latex_types.symbol },
  "vdash": { insertText: "vdash", documentation: "Binary Relation: vdash", kind: latex_types.symbol },
  "mid": { insertText: "mid", documentation: "Binary Relation: mid", kind: latex_types.symbol },
  "smile": { insertText: "smile", documentation: "Binary Relation: smile", kind: latex_types.symbol },
  "geq": { insertText: "geq", detail: "Synonym for \"\\ge\"", documentation: "Binary Relation: geq", kind: latex_types.symbol },
  "gg": { insertText: "gg", documentation: "Binary Relation: gg", kind: latex_types.symbol },
  "succ": { insertText: "succ", documentation: "Binary Relation: succ", kind: latex_types.symbol },
  "succeq": { insertText: "succeq", documentation: "Binary Relation: succeq", kind: latex_types.symbol },
  "supset": { insertText: "supset", documentation: "Binary Relation: supset", kind: latex_types.symbol },
  "supseteq": { insertText: "supseteq", documentation: "Binary Relation: supseteq", kind: latex_types.symbol },
  "sqsupseteq": { insertText: "sqsupseteq", documentation: "Binary Relation: sqsupseteq", kind: latex_types.symbol },
  "ni": { insertText: "ni", detail: "Synonym for \"\\owns\"", documentation: "Binary Relation: ni", kind: latex_types.symbol },
  "dashv": { insertText: "dashv", documentation: "Binary Relation: dashv", kind: latex_types.symbol },
  "parallel": { insertText: "parallel", documentation: "Binary Relation: parallel", kind: latex_types.symbol },
  "frown": { insertText: "frown", documentation: "Binary Relation: frown", kind: latex_types.symbol },
  "notin": { insertText: "notin", documentation: "Binary Relation: notin", kind: latex_types.symbol },
  "equiv": { insertText: "equiv", documentation: "Binary Relation: equiv", kind: latex_types.symbol },
  "doteq": { insertText: "doteq", documentation: "Binary Relation: doteq", kind: latex_types.symbol },
  "sim": { insertText: "sim", documentation: "Binary Relation: sim", kind: latex_types.symbol },
  "simeq": { insertText: "simeq", documentation: "Binary Relation: simeq", kind: latex_types.symbol },
  "approx": { insertText: "approx", documentation: "Binary Relation: approx", kind: latex_types.symbol },
  "cong": { insertText: "cong", documentation: "Binary Relation: cong", kind: latex_types.symbol },
  "Join": { insertText: "Join", documentation: "Binary Relation: Join", kind: latex_types.symbol, detail: required_latexsym },
  "bowtie": { insertText: "bowtie", documentation: "Binary Relation: bowtie", kind: latex_types.symbol },
  "propto": { insertText: "propto", documentation: "Binary Relation: propto", kind: latex_types.symbol },
  "models": { insertText: "models", documentation: "Binary Relation: models", kind: latex_types.symbol },
  "perp": { insertText: "perp", documentation: "Binary Relation: perp", kind: latex_types.symbol },
  "asymp": { insertText: "asymp", documentation: "Binary Relation: asymp", kind: latex_types.symbol },
  "neq": { insertText: "neq", documentation: "Binary Relation: not equal", kind: latex_types.symbol },

  "pm": { insertText: "pm", documentation: "Binary Relation: pm", kind: latex_types.symbol },
  "cdot": { insertText: "cdot", documentation: "Binary Relation: cdot", kind: latex_types.symbol },
  "times": { insertText: "times", documentation: "Binary Relation: times", kind: latex_types.symbol },
  "cup": { insertText: "cup", documentation: "Binary Relation: cup", kind: latex_types.symbol },
  "sqcup": { insertText: "sqcup", documentation: "Binary Relation: sqcup", kind: latex_types.symbol },
  "vee": { insertText: "vee", documentation: "Binary Relation: vee", kind: latex_types.symbol, detail: "Synonym for \"\\lor\"" },
  "lor": { insertText: "lor", documentation: "Binary Relation: lor", kind: latex_types.symbol, detail: "Synonym for \"\\vee\"" },
  "oplus": { insertText: "oplus", documentation: "Binary Relation: oplus", kind: latex_types.symbol },
  "odot": { insertText: "odot", documentation: "Binary Relation: odot", kind: latex_types.symbol },
  "otimes": { insertText: "otimes", documentation: "Binary Relation: otimes", kind: latex_types.symbol },
  "bigtriangleup": { insertText: "bigtriangleup", documentation: "Binary Relation: bigtriangleup", kind: latex_types.symbol },
  "lhd": { insertText: "lhd", documentation: "Binary Relation: lhd", kind: latex_types.symbol, detail: required_latexsym },
  "unlhd": { insertText: "unlhd", documentation: "Binary Relation: unlhd", kind: latex_types.symbol, detail: required_latexsym },
  "mp": { insertText: "mp", documentation: "Binary Relation: mp", kind: latex_types.symbol },
  "div": { insertText: "div", documentation: "Binary Relation: div", kind: latex_types.symbol },
  "setminus": { insertText: "setminus", documentation: "Binary Relation: setminus", kind: latex_types.symbol },
  "cap": { insertText: "cap", documentation: "Binary Relation: cap", kind: latex_types.symbol },
  "sqcap": { insertText: "sqcap", documentation: "Binary Relation: sqcap", kind: latex_types.symbol },
  "wedge": { insertText: "wedge", documentation: "Binary Relation: wedge", kind: latex_types.symbol, detail: "Synonym for \"\\land\"" },
  "land": { insertText: "land", documentation: "Binary Relation: land", kind: latex_types.symbol, detail: "Synonym for \"\\wedge\"" },
  "ominus": { insertText: "ominus", documentation: "Binary Relation: ominus", kind: latex_types.symbol },
  "oslash": { insertText: "oslash", documentation: "Binary Relation: oslash", kind: latex_types.symbol },
  "bigcirc": { insertText: "bigcirc", documentation: "Binary Relation: bigcirc", kind: latex_types.symbol },
  "bigtriangledown": { insertText: "bigtriangledown", documentation: "Binary Relation: bigtriangledown", kind: latex_types.symbol },
  "rhd": { insertText: "rhd", documentation: "Binary Relation: rhd", kind: latex_types.symbol, detail: required_latexsym },
  "unrhd": { insertText: "unrhd", documentation: "Binary Relation: unrhd", kind: latex_types.symbol, detail: required_latexsym },
  "triangleleft": { insertText: "triangleleft", documentation: "Binary Relation: triangleleft", kind: latex_types.symbol },
  "triangleright": { insertText: "triangleright", documentation: "Binary Relation: triangleright", kind: latex_types.symbol },
  "star": { insertText: "star", documentation: "Binary Relation: star", kind: latex_types.symbol },
  "ast": { insertText: "ast", documentation: "Binary Relation: ast", kind: latex_types.symbol },
  "circ": { insertText: "circ", documentation: "Binary Relation: circ", kind: latex_types.symbol },
  "bullet": { insertText: "bullet", documentation: "Binary Relation: bullet", kind: latex_types.symbol },
  "diamond": { insertText: "diamond", documentation: "Binary Relation: diamond", kind: latex_types.symbol },
  "uplus": { insertText: "uplus", documentation: "Binary Relation: uplus", kind: latex_types.symbol },
  "amalg": { insertText: "amalg", documentation: "Binary Relation: amalg", kind: latex_types.symbol },
  "dagger": { insertText: "dagger", documentation: "Binary Relation: dagger", kind: latex_types.symbol },
  "ddagger": { insertText: "ddagger", documentation: "Binary Relation: ddagger", kind: latex_types.symbol },
  "wr": { insertText: "wr", documentation: "Binary Relation: wr", kind: latex_types.symbol },

  "sum": { insertText: "sum_{$1}^{$2} $0", documentation: "Operator: Sum", kind: latex_types.snippet },
  "prod": { insertText: "prod_{$1}^{$2} $0", documentation: "Operator: Product", kind: latex_types.snippet },
  "coprod": { insertText: "coprod_{$1}^{$2} $0", documentation: "Operator: Coproduct", kind: latex_types.snippet },
  "int": { insertText: "int_{$1}^{$2} $0", documentation: "Operator: Integral", kind: latex_types.snippet },
  "iint": { insertText: "iint_{$1}^{$2} $0", documentation: "Operator: double Integral", kind: latex_types.snippet },
  "iiint": { insertText: "iiint_{$1}^{$2} $0", documentation: "Operator: trible Integral", kind: latex_types.snippet },
  "bigoplus": { insertText: "bigoplus_{$1}^{$2} $0", documentation: "Operator: bigoplus", kind: latex_types.snippet },
  "bigcup": { insertText: "bigcup_{$1}^{$2} $0", documentation: "Operator: bigcup", kind: latex_types.snippet },
  "bigcap": { insertText: "bigcap_{$1}^{$2} $0", documentation: "Operator: bigcap", kind: latex_types.snippet },
  "bigsqcup": { insertText: "bigsqcup_{$1}^{$2} $0", documentation: "Operator: bigsqcup", kind: latex_types.snippet },
  "oint": { insertText: "oint_{$1}^{$2} $0", documentation: "Operator: cloused courve Integral", kind: latex_types.snippet },
  "bigotimes": { insertText: "bigotimes_{$1}^{$2} $0", documentation: "Operator: bigotimes", kind: latex_types.snippet },
  "bigvee": { insertText: "bigvee_{$1}^{$2} $0", documentation: "Operator: bigvee", kind: latex_types.snippet },
  "bigwedge": { insertText: "bigwedge_{$1}^{$2} $0", documentation: "Operator: bigwedge", kind: latex_types.snippet },
  "biguplus": { insertText: "biguplus_{$1}^{$2} $0", documentation: "Operator: biguplus", kind: latex_types.snippet },
  "bigodot": { insertText: "bigodot_{$1}^{$2} $0", documentation: "Operator: bigodot", kind: latex_types.snippet },

  "leftarrow": { insertText: "leftarrow", documentation: "Arrow: leftarrow", kind: latex_types.symbol, detail: "Synonym for \"\\gets\"" },
  "gets": { insertText: "gets", documentation: "Arrow: leftarrow", kind: latex_types.symbol, detail: "Synonym for \"\\leftarrow\"" },
  "rightarrow": { insertText: "rightarrow", documentation: "Arrow: rightarrow", kind: latex_types.symbol, detail: "Synonym for \"\\to\"" },
  "to": { insertText: "to", documentation: "Arrow: to", kind: latex_types.symbol, detail: "Synonym for \"\\rightarrow\"" },
  "leftrightarrow": { insertText: "leftrightarrow", documentation: "Arrow: leftrightarrow", kind: latex_types.symbol },
  "Leftarrow": { insertText: "Leftarrow", documentation: "Arrow: Leftarrow", kind: latex_types.symbol },
  "Rightarrow": { insertText: "Rightarrow", documentation: "Arrow: Rightarrow", kind: latex_types.symbol },
  "Leftrightarrow": { insertText: "Leftrightarrow", documentation: "Arrow: Leftrightarrow", kind: latex_types.symbol },
  "mapsto": { insertText: "mapsto", documentation: "Arrow: mapsto", kind: latex_types.symbol },
  "hookleftarrow": { insertText: "hookleftarrow", documentation: "Arrow: hookleftarrow", kind: latex_types.symbol },
  "leftharpoonup": { insertText: "leftharpoonup", documentation: "Arrow: leftharpoonup", kind: latex_types.symbol },
  "leftharpoondown": { insertText: "leftharpoondown", documentation: "Arrow: leftharpoondown", kind: latex_types.symbol },
  "rightleftharpoons": { insertText: "rightleftharpoons", documentation: "Arrow: rightleftharpoons", kind: latex_types.symbol },
  "uparrow": { insertText: "uparrow", documentation: "Arrow: uparrow", kind: latex_types.symbol },
  "updownarrow": { insertText: "updownarrow", documentation: "Arrow: updownarrow", kind: latex_types.symbol },
  "Downarrow": { insertText: "Downarrow", documentation: "Arrow: Downarrow", kind: latex_types.symbol },
  "nearrow": { insertText: "nearrow", documentation: "Arrow: nearrow", kind: latex_types.symbol },
  "swarrow": { insertText: "swarrow", documentation: "Arrow: swarrow", kind: latex_types.symbol },
  "leadsto": { insertText: "leadsto", documentation: "Arrow: leadsto", kind: latex_types.symbol, detail: required_latexsym },
  "longleftarrow": { insertText: "longleftarrow", documentation: "Arrow: longleftarrow", kind: latex_types.symbol },
  "longrightarrow": { insertText: "longrightarrow", documentation: "Arrow: longrightarrow", kind: latex_types.symbol },
  "longleftrightarrow": { insertText: "longleftrightarrow", documentation: "Arrow: longleftrightarrow", kind: latex_types.symbol },
  "Longleftarrow": { insertText: "Longleftarrow", documentation: "Arrow: Longleftarrow", kind: latex_types.symbol },
  "Longrightarrow": { insertText: "Longrightarrow", documentation: "Arrow: Longrightarrow", kind: latex_types.symbol },
  "Longleftrightarrow": { insertText: "Longleftrightarrow", documentation: "Arrow: Longleftrightarrow", kind: latex_types.symbol },
  "longmapsto": { insertText: "longmapsto", documentation: "Arrow: longmapsto", kind: latex_types.symbol },
  "hookrightarrow": { insertText: "hookrightarrow", documentation: "Arrow: hookrightarrow", kind: latex_types.symbol },
  "rightharpoonup": { insertText: "rightharpoonup", documentation: "Arrow: rightharpoonup", kind: latex_types.symbol },
  "rightharpoondown": { insertText: "rightharpoondown", documentation: "Arrow: rightharpoondown", kind: latex_types.symbol },
  "iff": { insertText: "iff", documentation: "Arrow: if", kind: latex_types.symbol, detail: "bigger spaces" },
  "downarrow": { insertText: "downarrow", documentation: "Arrow: downarrow", kind: latex_types.symbol },
  "Uparrow": { insertText: "Uparrow", documentation: "Arrow: Uparrow", kind: latex_types.symbol },
  "Updownarrow": { insertText: "Updownarrow", documentation: "Arrow: Updownarrow", kind: latex_types.symbol },
  "searrow": { insertText: "searrow", documentation: "Arrow: searrow", kind: latex_types.symbol },
  "nwarrow": { insertText: "nwarrow", documentation: "Arrow: nwarrow", kind: latex_types.symbol },

  "lfloor": { insertText: "lfloor", documentation: "Delimiter: left floor", kind: latex_types.symbol },
  "rfloor": { insertText: "lfloor", documentation: "Delimiter: right floor", kind: latex_types.symbol },
  "lceil": { insertText: "lceil", documentation: "Delimiter: left ceil", kind: latex_types.symbol },
  "rceil": { insertText: "rceil", documentation: "Delimiter: right ceil", kind: latex_types.symbol },
  "langle": { insertText: "langle", documentation: "Delimiter: left angle", kind: latex_types.symbol },
  "rangle": { insertText: "rangle", documentation: "Delimiter: right angle", kind: latex_types.symbol },
  "Vert": { insertText: "Vert", documentation: "Delimiter: double vertical", kind: latex_types.symbol },
  
  "neg": { insertText: "neg", documentation: "Symbol: neg", kind: latex_types.symbol, detail: "Synonym for \"\\\\lnot\"" },
  "lnot": { insertText: "lnot", documentation: "Symbol: lnot", kind: latex_types.symbol, detail: "Synonym for \"\\\\neg\"" },
  "top": { insertText: "top", documentation: "Symbol: top", kind: latex_types.symbol },
  "wp": { insertText: "wp", documentation: "Symbol: wp", kind: latex_types.symbol },
  "Diamond": { insertText: "Diamond", documentation: "Symbol: Diamond", kind: latex_types.symbol, detail: required_latexsym },
  "sharp": { insertText: "sharp", documentation: "Symbol: sharp", kind: latex_types.symbol },
  "digamma": { insertText: "digamma", documentation: "Symbol: digamma", kind: latex_types.symbol, detail: required_amsmath },
  "beth": { insertText: "beth", documentation: "Symbol: beth", kind: latex_types.symbol, detail: required_amsmath },
  "gimel": { insertText: "gimel", documentation: "Symbol: gimel", kind: latex_types.symbol, detail: required_amsmath },
  "daleth": { insertText: "daleth", documentation: "Symbol: daleth", kind: latex_types.symbol, detail: required_amsmath },

  // AMS Binary Relations.
  "dotplus": { insertText: "dotplus", documentation: "Binary Relation: dotplus", kind: latex_types.symbol, detail: required_amsmath },
  "ltimes": { insertText: "ltimes", documentation: "Binary Relation: ltimes", kind: latex_types.symbol, detail: required_amsmath },
  "doublecup": { insertText: "doublecup", documentation: "Binary Relation: doublecup", kind: latex_types.symbol, detail: required_amsmath },
  "veebar": { insertText: "veebar", documentation: "Binary Relation: veebar", kind: latex_types.symbol, detail: required_amsmath },
  "boxplus": { insertText: "boxplus", documentation: "Binary Relation: boxplus", kind: latex_types.symbol, detail: required_amsmath },
  "boxtimes": { insertText: "boxtimes", documentation: "Binary Relation: boxtimes", kind: latex_types.symbol, detail: required_amsmath },
  "intercal": { insertText: "intercal", documentation: "Binary Relation: intercal", kind: latex_types.symbol, detail: required_amsmath },
  "curlyvee": { insertText: "curlyvee", documentation: "Binary Relation: curlyvee", kind: latex_types.symbol, detail: required_amsmath },
  "centerdot": { insertText: "centerdot", documentation: "Binary Relation: centerdot", kind: latex_types.symbol, detail: required_amsmath },
  "rtimes": { insertText: "rtimes", documentation: "Binary Relation: rtimes", kind: latex_types.symbol, detail: required_amsmath },
  "doublecap": { insertText: "doublecap", documentation: "Binary Relation: doublecap", kind: latex_types.symbol, detail: required_amsmath },
  "barwedge": { insertText: "barwedge", documentation: "Binary Relation: barwedge", kind: latex_types.symbol, detail: required_amsmath },
  "boxminus": { insertText: "boxminus", documentation: "Binary Relation: boxminus", kind: latex_types.symbol, detail: required_amsmath },
  "boxdot": { insertText: "boxdot", documentation: "Binary Relation: boxdot", kind: latex_types.symbol, detail: required_amsmath },
  "circledast": { insertText: "circledast", documentation: "Binary Relation: circledast", kind: latex_types.symbol, detail: required_amsmath },
  "curlywedge": { insertText: "curlywedge", documentation: "Binary Relation: curlywedge", kind: latex_types.symbol, detail: required_amsmath },
  "divideontimes": { insertText: "divideontimes", documentation: "Binary Relation: divideontimes", kind: latex_types.symbol, detail: required_amsmath },
  "smallsetminus": { insertText: "smallsetminus", documentation: "Binary Relation: smallsetminus", kind: latex_types.symbol, detail: required_amsmath },
  "doublebarwedge": { insertText: "doublebarwedge", documentation: "Binary Relation: doublebarwedge", kind: latex_types.symbol, detail: required_amsmath },
  "circleddash": { insertText: "circleddash", documentation: "Binary Relation: circleddash", kind: latex_types.symbol, detail: required_amsmath },
  "circledcirc": { insertText: "circledcirc", documentation: "Binary Relation: circledcirc", kind: latex_types.symbol, detail: required_amsmath },
  "rightthreetimes": { insertText: "rightthreetimes", documentation: "Binary Relation: rightthreetimes", kind: latex_types.symbol, detail: required_amsmath },
  "leftthreetimes": { insertText: "leftthreetimes", documentation: "Binary Relation: leftthreetimes", kind: latex_types.symbol, detail: required_amsmath },
  "lessdot": { insertText: "lessdot", documentation: "Binary Relation: lessdot", kind: latex_types.symbol, detail: required_amsmath },
  "leqslant": { insertText: "leqslant", documentation: "Binary Relation: leqslant", kind: latex_types.symbol, detail: required_amsmath },
  "eqslantless": { insertText: "eqslantless", documentation: "Binary Relation: eqslantless", kind: latex_types.symbol, detail: required_amsmath },
  "leqq": { insertText: "leqq", documentation: "Binary Relation: leqq", kind: latex_types.symbol, detail: required_amsmath },
  "llless": { insertText: "llless", documentation: "Binary Relation: llless", kind: latex_types.symbol, detail: "Synonym for \"\\lll\". Required package \"amsmath\"" },
  "lll": { insertText: "lll", documentation: "Binary Relation: lll", kind: latex_types.symbol, detail: "Synonym for \"\\llless\". Required package \"amsmath\"" },
  "lesssim": { insertText: "lesssim", documentation: "Binary Relation: lesssim", kind: latex_types.symbol, detail: required_amsmath },
  "lessapprox": { insertText: "lessapprox", documentation: "Binary Relation: lessapprox", kind: latex_types.symbol, detail: required_amsmath },
  "lessgtr": { insertText: "lessgtr", documentation: "Binary Relation: lessgtr", kind: latex_types.symbol, detail: required_amsmath },
  "lesseqgtr": { insertText: "lesseqgtr", documentation: "Binary Relation: lesseqgtr", kind: latex_types.symbol, detail: required_amsmath },
  "lesseqqgtr": { insertText: "lesseqqgtr", documentation: "Binary Relation: lesseqqgtr", kind: latex_types.symbol, detail: required_amsmath },
  "preccurlyeq": { insertText: "preccurlyeq", documentation: "Binary Relation: preccurlyeq", kind: latex_types.symbol, detail: required_amsmath },
  "curlyeqprec": { insertText: "curlyeqprec", documentation: "Binary Relation: curlyeqprec", kind: latex_types.symbol, detail: required_amsmath },
  "precsim": { insertText: "precsim", documentation: "Binary Relation: precsim", kind: latex_types.symbol, detail: required_amsmath },
  "precapprox": { insertText: "precapprox", documentation: "Binary Relation: precapprox", kind: latex_types.symbol, detail: required_amsmath },
  "subseteqq": { insertText: "subseteqq", documentation: "Binary Relation: subseteqq", kind: latex_types.symbol, detail: required_amsmath },
  "shortparallel": { insertText: "shortparallel", documentation: "Binary Relation: shortparallel", kind: latex_types.symbol, detail: required_amsmath },
  "blacktriangleleft": { insertText: "blacktriangleleft", documentation: "Binary Relation: blacktriangleleft", kind: latex_types.symbol, detail: required_amsmath },
  "vartriangleright": { insertText: "vartriangleright", documentation: "Binary Relation: vartriangleright", kind: latex_types.symbol, detail: required_amsmath },
  "blacktriangleright": { insertText: "blacktriangleright", documentation: "Binary Relation: blacktriangleright", kind: latex_types.symbol, detail: required_amsmath },
  "trianglerighteq": { insertText: "trianglerighteq", documentation: "Binary Relation: trianglerighteq", kind: latex_types.symbol, detail: required_amsmath },
  "vartriangleleft": { insertText: "vartriangleleft", documentation: "Binary Relation: vartriangleleft", kind: latex_types.symbol, detail: required_amsmath },
  "trianglelefteq": { insertText: "trianglelefteq", documentation: "Binary Relation: trianglelefteq", kind: latex_types.symbol, detail: required_amsmath },
  "gtrdot": { insertText: "gtrdot", documentation: "Binary Relation: gtrdot", kind: latex_types.symbol, detail: required_amsmath },
  "geqslant": { insertText: "geqslant", documentation: "Binary Relation: geqslant", kind: latex_types.symbol, detail: required_amsmath },
  "eqslantgtr": { insertText: "eqslantgtr", documentation: "Binary Relation: eqslantgtr", kind: latex_types.symbol, detail: required_amsmath },
  "geqq": { insertText: "geqq", documentation: "Binary Relation: geqq", kind: latex_types.symbol, detail: required_amsmath },
  "ggg": { insertText: "ggg", documentation: "Binary Relation: ggg", kind: latex_types.symbol, detail: required_amsmath },
  "gtrsim": { insertText: "gtrsim", documentation: "Binary Relation: gtrsim", kind: latex_types.symbol, detail: required_amsmath },
  "gtrapprox": { insertText: "gtrapprox", documentation: "Binary Relation: gtrapprox", kind: latex_types.symbol, detail: required_amsmath },
  "gtrless": { insertText: "gtrless", documentation: "Binary Relation: gtrless", kind: latex_types.symbol, detail: required_amsmath },
  "gtreqless": { insertText: "gtreqless", documentation: "Binary Relation: gtreqless", kind: latex_types.symbol, detail: required_amsmath },
  "gtreqqless": { insertText: "gtreqqless", documentation: "Binary Relation: gtreqqless", kind: latex_types.symbol, detail: required_amsmath },
  "succcurlyeq": { insertText: "succcurlyeq", documentation: "Binary Relation: succcurlyeq", kind: latex_types.symbol, detail: required_amsmath },
  "curlyeqsucc": { insertText: "curlyeqsucc", documentation: "Binary Relation: curlyeqsucc", kind: latex_types.symbol, detail: required_amsmath },
  "succsim": { insertText: "succsim", documentation: "Binary Relation: succsim", kind: latex_types.symbol, detail: required_amsmath },
  "succapprox": { insertText: "succapprox", documentation: "Binary Relation: succapprox", kind: latex_types.symbol, detail: required_amsmath },
  "supseteqq": { insertText: "supseteqq", documentation: "Binary Relation: supseteqq", kind: latex_types.symbol, detail: required_amsmath },
  "Supset": { insertText: "Supset", documentation: "Binary Relation: Supset", kind: latex_types.symbol, detail: required_amsmath },
  "sqsupset": { insertText: "sqsupset", documentation: "Binary Relation: sqsupset", kind: latex_types.symbol, detail: required_amsmath },
  "because": { insertText: "because", documentation: "Binary Relation: because", kind: latex_types.symbol, detail: required_amsmath },
  "Subset": { insertText: "Subset", documentation: "Binary Relation: Subset", kind: latex_types.symbol, detail: required_amsmath },
  "smallfrown": { insertText: "smallfrown", documentation: "Binary Relation: smallfrown", kind: latex_types.symbol, detail: required_amsmath },
  "shortmid": { insertText: "shortmid", documentation: "Binary Relation: shortmid", kind: latex_types.symbol, detail: required_amsmath },
  "therefore": { insertText: "therefore", documentation: "Binary Relation: therefore", kind: latex_types.symbol, detail: required_amsmath },
  "doteqdot": { insertText: "doteqdot", documentation: "Binary Relation: doteqdot", kind: latex_types.symbol, detail: required_amsmath },
  "risingdotseq": { insertText: "risingdotseq", documentation: "Binary Relation: risingdotseq", kind: latex_types.symbol, detail: required_amsmath },
  "fallingdotseq": { insertText: "fallingdotseq", documentation: "Binary Relation: fallingdotseq", kind: latex_types.symbol, detail: required_amsmath },
  "eqcirc": { insertText: "eqcirc", documentation: "Binary Relation: eqcirc", kind: latex_types.symbol, detail: required_amsmath },
  "circeq": { insertText: "circeq", documentation: "Binary Relation: circeq", kind: latex_types.symbol, detail: required_amsmath },
  "triangleq": { insertText: "triangleq", documentation: "Binary Relation: triangleq", kind: latex_types.symbol, detail: required_amsmath },
  "bumpeq": { insertText: "bumpeq", documentation: "Binary Relation: bumpeq", kind: latex_types.symbol, detail: required_amsmath },
  "Bumpeq": { insertText: "Bumpeq", documentation: "Binary Relation: Bumpeq", kind: latex_types.symbol, detail: required_amsmath },
  "thicksim": { insertText: "thicksim", documentation: "Binary Relation: thicksim", kind: latex_types.symbol, detail: required_amsmath },
  "thickapprox": { insertText: "thickapprox", documentation: "Binary Relation: thickapprox", kind: latex_types.symbol, detail: required_amsmath },
  "approxeq": { insertText: "approxeq", documentation: "Binary Relation: approxeq", kind: latex_types.symbol, detail: required_amsmath },
  "backsim": { insertText: "backsim", documentation: "Binary Relation: backsim", kind: latex_types.symbol, detail: required_amsmath },
  "backsimeq": { insertText: "backsimeq", documentation: "Binary Relation: backsimeq", kind: latex_types.symbol, detail: required_amsmath },
  "vDash": { insertText: "vDash", documentation: "Binary Relation: vDash", kind: latex_types.symbol, detail: required_amsmath },
  "Vdash": { insertText: "Vdash", documentation: "Binary Relation: Vdash", kind: latex_types.symbol, detail: required_amsmath },
  "Vvdash": { insertText: "Vvdash", documentation: "Binary Relation: Vvdash", kind: latex_types.symbol, detail: required_amsmath },
  "backepsilon": { insertText: "backepsilon", documentation: "Binary Relation: backepsilon", kind: latex_types.symbol, detail: required_amsmath },
  "varpropto": { insertText: "varpropto", documentation: "Binary Relation: varpropto", kind: latex_types.symbol, detail: required_amsmath },
  "between": { insertText: "between", documentation: "Binary Relation: between", kind: latex_types.symbol, detail: required_amsmath },
  "pitchfork": { insertText: "pitchfork", documentation: "Binary Relation: pitchfork", kind: latex_types.symbol, detail: required_amsmath },
  "smallsmile": { insertText: "smallsmile", documentation: "Binary Relation: smallsmile", kind: latex_types.symbol, detail: required_amsmath },
  "sqsubset": { insertText: "sqsubset", documentation: "Binary Relation: sqsubset", kind: latex_types.symbol, detail: required_amsmath },

  // AMS Arrows.
  "dashleftarrow": { insertText: "dashleftarrow", documentation: "Arrow: dashleftarrow", kind: latex_types.symbol, detail: required_amsmath },
  "leftleftarrows": { insertText: "leftleftarrows", documentation: "Arrow: leftleftarrows", kind: latex_types.symbol, detail: required_amsmath },
  "leftrightarrows": { insertText: "leftrightarrows", documentation: "Arrow: leftrightarrows", kind: latex_types.symbol, detail: required_amsmath },
  "Lleftarrow": { insertText: "Lleftarrow", documentation: "Arrow: Lleftarrow", kind: latex_types.symbol, detail: required_amsmath },
  "twoheadleftarrow": { insertText: "twoheadleftarrow", documentation: "Arrow: twoheadleftarrow", kind: latex_types.symbol, detail: required_amsmath },
  "leftarrowtail": { insertText: "leftarrowtail", documentation: "Arrow: leftarrowtail", kind: latex_types.symbol, detail: required_amsmath },
  "leftrightharpoons": { insertText: "leftrightharpoons", documentation: "Arrow: leftrightharpoons", kind: latex_types.symbol, detail: required_amsmath },
  "Lsh": { insertText: "Lsh", documentation: "Arrow: Lsh", kind: latex_types.symbol, detail: required_amsmath },
  "looparrowleft": { insertText: "looparrowleft", documentation: "Arrow: looparrowleft", kind: latex_types.symbol, detail: required_amsmath },
  "curvearrowleft": { insertText: "curvearrowleft", documentation: "Arrow: curvearrowleft", kind: latex_types.symbol, detail: required_amsmath },
  "circlearrowleft": { insertText: "circlearrowleft", documentation: "Arrow: circlearrowleft", kind: latex_types.symbol, detail: required_amsmath },
  "multimap": { insertText: "multimap", documentation: "Arrow: multimap", kind: latex_types.symbol, detail: required_amsmath },
  "downdownarrows": { insertText: "downdownarrows", documentation: "Arrow: downdownarrows", kind: latex_types.symbol, detail: required_amsmath },
  "upharpoonright": { insertText: "upharpoonright", documentation: "Arrow: upharpoonright", kind: latex_types.symbol, detail: required_amsmath },
  "rightsquigarrow": { insertText: "rightsquigarrow", documentation: "Arrow: rightsquigarrow", kind: latex_types.symbol, detail: required_amsmath },
  "dashrightarrow": { insertText: "dashrightarrow", documentation: "Arrow: dashrightarrow", kind: latex_types.symbol, detail: required_amsmath },
  "rightrightarrows": { insertText: "rightrightarrows", documentation: "Arrow: rightrightarrows", kind: latex_types.symbol, detail: required_amsmath },
  "rightleftarrows": { insertText: "rightleftarrows", documentation: "Arrow: rightleftarrows", kind: latex_types.symbol, detail: required_amsmath },
  "Rrightarrow": { insertText: "Rrightarrow", documentation: "Arrow: Rrightarrow", kind: latex_types.symbol, detail: required_amsmath },
  "twoheadrightarrow": { insertText: "twoheadrightarrow", documentation: "Arrow: twoheadrightarrow", kind: latex_types.symbol, detail: required_amsmath },
  "rightarrowtail": { insertText: "rightarrowtail", documentation: "Arrow: rightarrowtail", kind: latex_types.symbol, detail: required_amsmath },
  "Rsh": { insertText: "Rsh", documentation: "Arrow: Rsh", kind: latex_types.symbol, detail: required_amsmath },
  "looparrowright": { insertText: "looparrowright", documentation: "Arrow: looparrowright", kind: latex_types.symbol, detail: required_amsmath },
  "curvearrowright": { insertText: "curvearrowright", documentation: "Arrow: curvearrowright", kind: latex_types.symbol, detail: required_amsmath },
  "circlearrowright": { insertText: "circlearrowright", documentation: "Arrow: circlearrowright", kind: latex_types.symbol, detail: required_amsmath },
  "upuparrows": { insertText: "upuparrows", documentation: "Arrow: upuparrows", kind: latex_types.symbol, detail: required_amsmath },
  "upharpoonleft": { insertText: "upharpoonleft", documentation: "Arrow: upharpoonleft", kind: latex_types.symbol, detail: required_amsmath },
  "downharpoonright": { insertText: "downharpoonright", documentation: "Arrow: downharpoonright", kind: latex_types.symbol, detail: required_amsmath },
  "leftrightsquigarrow": { insertText: "leftrightsquigarrow", documentation: "Arrow: leftrightsquigarrow", kind: latex_types.symbol, detail: required_amsmath },

  // AMS Negated Binary Relations and Arrows.
  "nless": { insertText: "nless", documentation: "Negated Binary Relation: nless", kind: latex_types.symbol, detail: required_amsmath },
  "lneq": { insertText: "lneq", documentation: "Negated Binary Relation: lneq", kind: latex_types.symbol, detail: required_amsmath },
  "nleq": { insertText: "nleq", documentation: "Negated Binary Relation: nleq", kind: latex_types.symbol, detail: required_amsmath },
  "nleqslant": { insertText: "nleqslant", documentation: "Negated Binary Relation: nleqslant", kind: latex_types.symbol, detail: required_amsmath },
  "lneqq": { insertText: "lneqq", documentation: "Negated Binary Relation: lneqq", kind: latex_types.symbol, detail: required_amsmath },
  "lvertneqq": { insertText: "lvertneqq", documentation: "Negated Binary Relation: lvertneqq", kind: latex_types.symbol, detail: required_amsmath },
  "nleqq": { insertText: "nleqq", documentation: "Negated Binary Relation: nleqq", kind: latex_types.symbol, detail: required_amsmath },
  "lnsim": { insertText: "lnsim", documentation: "Negated Binary Relation: lnsim", kind: latex_types.symbol, detail: required_amsmath },
  "lnapprox": { insertText: "lnapprox", documentation: "Negated Binary Relation: lnapprox", kind: latex_types.symbol, detail: required_amsmath },
  "nprec": { insertText: "nprec", documentation: "Negated Binary Relation: nprec", kind: latex_types.symbol, detail: required_amsmath },
  "npreceq": { insertText: "npreceq", documentation: "Negated Binary Relation: npreceq", kind: latex_types.symbol, detail: required_amsmath },
  "precneqq": { insertText: "precneqq", documentation: "Negated Binary Relation: precneqq", kind: latex_types.symbol, detail: required_amsmath },
  "precnsim": { insertText: "precnsim", documentation: "Negated Binary Relation: precnsim", kind: latex_types.symbol, detail: required_amsmath },
  "precnapprox": { insertText: "precnapprox", documentation: "Negated Binary Relation: precnapprox", kind: latex_types.symbol, detail: required_amsmath },
  "subsetneq": { insertText: "subsetneq", documentation: "Negated Binary Relation: subsetneq", kind: latex_types.symbol, detail: required_amsmath },
  "varsubsetneq": { insertText: "varsubsetneq", documentation: "Negated Binary Relation: varsubsetneq", kind: latex_types.symbol, detail: required_amsmath },
  "nsubseteq": { insertText: "nsubseteq", documentation: "Negated Binary Relation: nsubseteq", kind: latex_types.symbol, detail: required_amsmath },
  "subsetneqq": { insertText: "subsetneqq", documentation: "Negated Binary Relation: subsetneqq", kind: latex_types.symbol, detail: required_amsmath },
  "ngtr": { insertText: "ngtr", documentation: "Negated Binary Relation: ngtr", kind: latex_types.symbol, detail: required_amsmath },
  "gneq": { insertText: "gneq", documentation: "Negated Binary Relation: gneq", kind: latex_types.symbol, detail: required_amsmath },
  "ngeq": { insertText: "ngeq", documentation: "Negated Binary Relation: ngeq", kind: latex_types.symbol, detail: required_amsmath },
  "ngeqslant": { insertText: "ngeqslant", documentation: "Negated Binary Relation: ngeqslant", kind: latex_types.symbol, detail: required_amsmath },
  "gneqq": { insertText: "gneqq", documentation: "Negated Binary Relation: gneqq", kind: latex_types.symbol, detail: required_amsmath },
  "gvertneqq": { insertText: "gvertneqq", documentation: "Negated Binary Relation: gvertneqq", kind: latex_types.symbol, detail: required_amsmath },
  "ngeqq": { insertText: "ngeqq", documentation: "Negated Binary Relation: ngeqq", kind: latex_types.symbol, detail: required_amsmath },
  "gnsim": { insertText: "gnsim", documentation: "Negated Binary Relation: gnsim", kind: latex_types.symbol, detail: required_amsmath },
  "gnapprox": { insertText: "gnapprox", documentation: "Negated Binary Relation: gnapprox", kind: latex_types.symbol, detail: required_amsmath },
  "nsucc": { insertText: "nsucc", documentation: "Negated Binary Relation: nsucc", kind: latex_types.symbol, detail: required_amsmath },
  "nsucceq": { insertText: "nsucceq", documentation: "Negated Binary Relation: nsucceq", kind: latex_types.symbol, detail: required_amsmath },
  "succneqq": { insertText: "succneqq", documentation: "Negated Binary Relation: succneqq", kind: latex_types.symbol, detail: required_amsmath },
  "succnsim": { insertText: "succnsim", documentation: "Negated Binary Relation: succnsim", kind: latex_types.symbol, detail: required_amsmath },
  "succnapprox": { insertText: "succnapprox", documentation: "Negated Binary Relation: succnapprox", kind: latex_types.symbol, detail: required_amsmath },
  "supsetneq": { insertText: "supsetneq", documentation: "Negated Binary Relation: supsetneq", kind: latex_types.symbol, detail: required_amsmath },
  "varsupsetneq": { insertText: "varsupsetneq", documentation: "Negated Binary Relation: varsupsetneq", kind: latex_types.symbol, detail: required_amsmath },
  "nsupseteq": { insertText: "nsupseteq", documentation: "Negated Binary Relation: nsupseteq", kind: latex_types.symbol, detail: required_amsmath },
  "supsetneqq": { insertText: "supsetneqq", documentation: "Negated Binary Relation: supsetneqq", kind: latex_types.symbol, detail: required_amsmath },
  "varsubsetneqq": { insertText: "varsubsetneqq", documentation: "Negated Binary Relation: varsubsetneqq", kind: latex_types.symbol, detail: required_amsmath },
  "varsupsetneqq": { insertText: "varsupsetneqq", documentation: "Negated Binary Relation: varsupsetneqq", kind: latex_types.symbol, detail: required_amsmath },
  "nsubseteqq": { insertText: "nsubseteqq", documentation: "Negated Binary Relation: nsubseteqq", kind: latex_types.symbol, detail: required_amsmath },
  "nsupseteqq": { insertText: "nsupseteqq", documentation: "Negated Binary Relation: nsupseteqq", kind: latex_types.symbol, detail: required_amsmath },
  "nmid": { insertText: "nmid", documentation: "Negated Binary Relation: nmid", kind: latex_types.symbol, detail: required_amsmath },
  "nparallel": { insertText: "nparallel", documentation: "Negated Binary Relation: nparallel", kind: latex_types.symbol, detail: required_amsmath },
  "nshortmid": { insertText: "nshortmid", documentation: "Negated Binary Relation: nshortmid", kind: latex_types.symbol, detail: required_amsmath },
  "nshortparallel": { insertText: "nshortparallel", documentation: "Negated Binary Relation: nshortparallel", kind: latex_types.symbol, detail: required_amsmath },
  "nsim": { insertText: "nsim", documentation: "Negated Binary Relation: nsim", kind: latex_types.symbol, detail: required_amsmath },
  "ncong": { insertText: "ncong", documentation: "Negated Binary Relation: ncong", kind: latex_types.symbol, detail: required_amsmath },
  "nvdash": { insertText: "nvdash", documentation: "Negated Binary Relation: nvdash", kind: latex_types.symbol, detail: required_amsmath },
  "nvDash": { insertText: "nvDash", documentation: "Negated Binary Relation: nvDash", kind: latex_types.symbol, detail: required_amsmath },
  "nVdash": { insertText: "nVdash", documentation: "Negated Binary Relation: nVdash", kind: latex_types.symbol, detail: required_amsmath },
  "nVDash": { insertText: "nVDash", documentation: "Negated Binary Relation: nVDash", kind: latex_types.symbol, detail: required_amsmath },
  "ntriangleleft": { insertText: "ntriangleleft", documentation: "Negated Binary Relation: ntriangleleft", kind: latex_types.symbol, detail: required_amsmath },
  "ntriangleright": { insertText: "ntriangleright", documentation: "Negated Binary Relation: ntriangleright", kind: latex_types.symbol, detail: required_amsmath },
  "ntrianglelefteq": { insertText: "ntrianglelefteq", documentation: "Negated Binary Relation: ntrianglelefteq", kind: latex_types.symbol, detail: required_amsmath },
  "ntrianglerighteq": { insertText: "ntrianglerighteq", documentation: "Negated Binary Relation: ntrianglerighteq", kind: latex_types.symbol, detail: required_amsmath },

  // AMS negated Arrows.
  "nleftarrow": { insertText: "nleftarrow", documentation: "Negated Arrow: nleftarrow", kind: latex_types.symbol, detail: required_amsmath },
  "nLeftarrow": { insertText: "nLeftarrow", documentation: "Negated Arrow: nLeftarrow", kind: latex_types.symbol, detail: required_amsmath },
  "nrightarrow": { insertText: "nrightarrow", documentation: "Negated Arrow: nrightarrow", kind: latex_types.symbol, detail: required_amsmath },
  "nRightarrow": { insertText: "nRightarrow", documentation: "Negated Arrow: nRightarrow", kind: latex_types.symbol, detail: required_amsmath },
  "nleftrightarrow": { insertText: "nleftrightarrow", documentation: "Negated Arrow: nleftrightarrow", kind: latex_types.symbol, detail: required_amsmath },
  "nLeftrightarrow": { insertText: "nLeftrightarrow", documentation: "Negated Arrow: nLeftrightarrow", kind: latex_types.symbol, detail: required_amsmath },

  // AMS Miscellaneous.
  "hbar": { insertText: "hbar", documentation: "Symbol: hbar", kind: latex_types.symbol, detail: required_amsmath },
  "square": { insertText: "square", documentation: "Symbol: square", kind: latex_types.symbol, detail: required_amsmath },
  "vartriangle": { insertText: "vartriangle", documentation: "Symbol: vartriangle", kind: latex_types.symbol, detail: required_amsmath },
  "triangledown": { insertText: "triangledown", documentation: "Symbol: triangledown", kind: latex_types.symbol, detail: required_amsmath },
  "lozenge": { insertText: "lozenge", documentation: "Symbol: lozenge", kind: latex_types.symbol, detail: required_amsmath },
  "angle": { insertText: "angle", documentation: "Symbol: angle", kind: latex_types.symbol, detail: required_amsmath },
  "diagup": { insertText: "diagup", documentation: "Symbol: diagup", kind: latex_types.symbol, detail: required_amsmath },
  "nexists": { insertText: "nexists", documentation: "Symbol: nexists", kind: latex_types.symbol, detail: required_amsmath },
  "eth": { insertText: "eth", documentation: "Symbol: eth", kind: latex_types.symbol, detail: required_amsmath },
  "hslash": { insertText: "hslash", documentation: "Symbol: hslash", kind: latex_types.symbol, detail: required_amsmath },
  "blacksquare": { insertText: "blacksquare", documentation: "Symbol: blacksquare", kind: latex_types.symbol, detail: required_amsmath },
  "blacktriangle": { insertText: "blacktriangle", documentation: "Symbol: blacktriangle", kind: latex_types.symbol, detail: required_amsmath },
  "blacktriangledown": { insertText: "blacktriangledown", documentation: "Symbol: blacktriangledown", kind: latex_types.symbol, detail: required_amsmath },
  "blacklozenge": { insertText: "blacklozenge", documentation: "Symbol: blacklozenge", kind: latex_types.symbol, detail: required_amsmath },
  "measuredangle": { insertText: "measuredangle", documentation: "Symbol: measuredangle", kind: latex_types.symbol, detail: required_amsmath },
  "diagdown": { insertText: "diagdown", documentation: "Symbol: diagdown", kind: latex_types.symbol, detail: required_amsmath },
  "Finv": { insertText: "Finv", documentation: "Symbol: Finv", kind: latex_types.symbol, detail: required_amsmath },
  "sphericalangle": { insertText: "sphericalangle", documentation: "Symbol: sphericalangle", kind: latex_types.symbol, detail: required_amsmath },
  "Bbbk": { insertText: "Bbbk", documentation: "Symbol: Bbbk", kind: latex_types.symbol, detail: required_amsmath },
  "circledS": { insertText: "circledS", documentation: "Symbol: circledS", kind: latex_types.symbol, detail: required_amsmath },
  "complement": { insertText: "complement", documentation: "Symbol: complement", kind: latex_types.symbol, detail: required_amsmath },
  "Game": { insertText: "Game", documentation: "Symbol: Game", kind: latex_types.symbol, detail: required_amsmath },
  "bigstar": { insertText: "bigstar", documentation: "Symbol: bigstar", kind: latex_types.symbol, detail: required_amsmath },
  "backprime": { insertText: "backprime", documentation: "Symbol: backprime", kind: latex_types.symbol, detail: required_amsmath },
  "varnothing": { insertText: "varnothing", documentation: "Symbol: varnothing", kind: latex_types.symbol, detail: required_amsmath },
  "mho": { insertText: "mho", documentation: "Symbol: mho", kind: latex_types.symbol, detail: required_amsmath },
};
